summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlatheedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlatheedit.h')
-rw-r--r--kpovmodeler/pmlatheedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmlatheedit.h b/kpovmodeler/pmlatheedit.h
index 92e92950..c33a9711 100644
--- a/kpovmodeler/pmlatheedit.h
+++ b/kpovmodeler/pmlatheedit.h
@@ -43,12 +43,13 @@ class TQLabel;
class PMLatheEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMLatheEdit with parent and name
*/
- PMLatheEdit( TQWidget* parent, const char* name = 0 );
+ PMLatheEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -43,12 +43,13 @@ class TQLabel;
public:
/**
- * Creates a PMLatheEdit with parent and name
+ * Creates a PMLatheEdit with tqparent and name
*/